/**
 * 入口文件
 * 识别命令，分发调用相应函数
 */

const chalk = require('chalk')
const cli = require('cac')()
const { version } = require('../package.json')
const webpackConfig = require('./webpack-config')
const { setMode } = require('./common/util')

/**
 * 启动开发项目命令
 */
cli
  .command('dev', '开发项目')
  .action((name, options) => {
    setMode('development')
    require('./dev')({ webpackConfig: webpackConfig() })
  })

/**
 * 启动构建项目命令
 */
cli
  .command('build', '构建项目')
  .action((name, options) => {
    setMode('production')
    require('./build')({ webpackConfig: webpackConfig() })
  })

/**
 * 未识别命令输出提示
 */
cli.on('command:*', () => {
  console.log(`${chalk.red.bold('Unknown Command.')} Run ${chalk.blue.bold('lf-engine -h')} for detailed usage.`)
})

cli.help()

cli.version(version)

cli.parse()
