/**
 * webpack 配置 - 插件
 */

const webpack = require('webpack')
const { getMode, isWithHash, isWithSourceMap } = require('../common/util')

module.exports = ({ config }) => {
  const mode = getMode()
  const hash = isWithHash()
  const sourceMap = isWithSourceMap()

  config
    .plugin('Vue')
    .use(require('vue-loader/lib/plugin'))

  config
    .plugin('Html')
    .use(require('html-webpack-plugin'), [{
      template: 'public/index.html',
      filename: 'index.html'
    }])

  const cssFilename = `css/[name]${hash}.css`
  config
    .plugin('MiniCss')
    .use(require('mini-css-extract-plugin'), [{
      filename: cssFilename,
      chunkFilename: cssFilename
    }])

  config
    .plugin('DefinePlugin')
    .use(webpack.DefinePlugin, [{
      'porcess.env.mode': `"${mode}"`
    }])

  // 开发环境插件
  if (mode === 'development') {
    config
      .plugin('FriendlyErrors')
      .use(require('friendly-errors-webpack-plugin'))

    config
      .plugin('HotModuleReplacementPlugin')
      .use(webpack.HotModuleReplacementPlugin)
  }

  // 构建环境插件
  if (mode === 'production') {
    config
      .plugin('Clean')
      .use(require('clean-webpack-plugin').CleanWebpackPlugin)

    config
      .plugin('Uglifyjs')
      .use(require('uglifyjs-webpack-plugin'), [{
        parallel: true,
        sourceMap
      }])

    config
      .plugin('OptimizeCss')
      .use(require('optimize-css-assets-webpack-plugin'), [{
        assetNameRegExp: /\.css$/g,
        cssProcessor: require('cssnano'),
        cssProcessorOptions: { autoprefixer: { browsers: ['> 0.01%'] } },
        canPrint: true
      }])

    config
      .plugin('ModuleConcatenation')
      .use(webpack.optimize.ModuleConcatenationPlugin)
  }
}
